defmodule AccessToken.Mixfile do
  use Mix.Project

  @version "2.0.0"

  def project do
    [
      app: :access_token,
      version: @version,
      elixir: "~> 1.4",
      elixirc_paths: elixirc_paths(Mix.env),
      deps: deps(),
      package: package(),
      preferred_cli_env: [docs: :docs],
      description: description(),
      docs: docs(),
      test_coverage: [tool: AccessToken.Cover]
    ]
  end

  def application do
    [
      extra_applications: [:crypto]
    ]
  end

  # Specifies which paths to compile per environment.
  defp elixirc_paths(:test), do: ["lib", "test/support"]
  defp elixirc_paths(_),     do: ["lib"]

  defp deps do
    [
      {:credo, "~> 0.8.10", only: :dev},
      {:ex_doc, "~> 0.18.1", only: :docs},
      {:plug, "~> 1.3.3 or ~> 1.4"}
    ]
  end

  defp description do
    """
    Access Token utility library.
    """
  end

  defp package do
    [
      maintainers: ["Fernando Tapia Rico"],
      licenses: ["MIT"],
      links: %{"GitHub" => "https://github.com/fertapric/access_token"},
      files: ~w(mix.exs LICENSE README.md lib)
    ]
  end

  defp docs do
    [
      source_ref: "v#{@version}",
      main: "AccessToken",
      canonical: "http://hexdocs.pm/access_token",
      source_url: "https://github.com/fertapric/access_token"
    ]
  end
end
